[−][src]Function ergo_node_interface::local_config::new_interface_from_yaml
pub fn new_interface_from_yaml(config: Yaml) -> Result<NodeInterface>
Uses the config yaml provided to create a new NodeInterface
pub fn new_interface_from_yaml(config: Yaml) -> Result<NodeInterface>
Uses the config yaml provided to create a new NodeInterface